@@ -8,7 +8,7 @@ Catalyst::Helper::Model::LDAP - Helper for LDAP models
 
 =head1 SYNOPSIS
 
-  script/myapp_create.pl model People LDAP ldap.ufl.edu ou=People,dc=ufl,dc=edu
+    script/myapp_create.pl model Person LDAP ldap.ufl.edu ou=People,dc=ufl,dc=edu
 
 =head1 DESCRIPTION
 
@@ -79,7 +79,6 @@ __PACKAGE__->config(
     dn           => '[% dn %]',
     password     => '[% password %]',
     options      => {},
-    cache        => undef,
 );
 
 =head1 NAME
